==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/lt_LT.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Išorinės saugyklos",
    "Personal" : "Asmeniniai",
    "System" : "Sistema",
    "Grant access" : "Suteikti prieigą",
    "Error configuring OAuth1" : "Klaida, konfigūruojant OAuth1",
    "Please provide a valid app key and secret." : "Prašome naudoti teisingus trečiųjų šalių programinės įrangos identifikacijos numerį ir slaptažodį.",
    "Error configuring OAuth2" : "Klaida, konfigūruojant OAuth2",
    "Generate keys" : "Sukurti raktus",
    "Error generating key pair" : "Klaida kuriant raktus",
    "All users. Type to select user or group." : "Visi naudotojai. Pradėkite rašyti, jei norite pasirinkti konkretų naudotoją ar grupę.",
    "(group)" : "(grupė)",
    "Compatibility with Mac NFD encoding (slow)" : "Suderinamumas su Mac NFD kodavimu (lėtai)",
    "Admin defined" : "Administratorius apibrėžtas",
    "Saved" : "Įrašyta",
    "Saving..." : "Įrašoma...",
    "Save" : "Įrašyti",
    "Empty response from the server" : "Negautas atsakymas iš serverio",
    "Couldn't access. Please log out and in again to activate this mount point" : "Prieiga yra neįmanoma. Pabandykite prisijungti iš naujo.",
    "Couldn't get the information from the remote server: {code} {type}" : "Neįmanoma gauti informacijos iš serverio: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nepavyko gauti išorinių prijungimo taškų sąrašo: {type}",
    "There was an error with message: " : "Klaidos žinutė:",
    "External mount error" : "Išorinio prijungimo klaida",
    "external-storage" : "išorinė saugykla",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Neįmanoma gauti duomenų sąrašo ir Windows tinkle prijungto disko. Nėra jokio atsakymo.",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Kai kurios sukonfigūruotos išorinės saugyklos nebuvo prijungtos. Paspauskite ant raudonai nuspalvotų eilučių norėdami gauti išsamesnę informaciją",
    "Please enter the credentials for the {mount} mount" : "Prašome įvesti prisijungimo duomenis skirtus saugyklos {mount} prijungimui",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Credentials saved" : "Prisijungimo duomenys yra išsaugoti",
    "Credentials saving failed" : "Nepavyko išsaugoti prisijungimo duomenų",
    "Credentials required" : "Reikalingi prisijungimo duomenys",
    "Storage with ID \"%d\" not found" : "Nerasta saugykla su identifikacijos numeriu \"%d\"",
    "Invalid backend or authentication mechanism class" : "Netinkama programinio kodo klasė realizuoja prisijungimo mechanizmą",
    "Invalid mount point" : "Neteisingas prijungimo taškas",
    "Objectstore forbidden" : "Objektų saugykla yra neprieinama",
    "Invalid storage backend \"%s\"" : "Netinkama saugyklos posistemė \"%s\"",
    "Not permitted to use backend \"%s\"" : "Neleidžiama naudoti posistemės \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Neleidžiama naudoti prisijungimo mechanizmo \"%s\"",
    "Unsatisfied backend parameters" : " Netinkami posistemės parametrai",
    "Unsatisfied authentication mechanism parameters" : "Netinkami parametrai perduoti į prisijungimo mechanizmą",
    "Insufficient data: %s" : "Trūksta duomenų: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Naudotojai negali redaguoti saugyklos identifikuotos kaip \"%d\"",
    "Access key" : "Prieigos raktas",
    "Secret key" : "Slaptažodis",
    "Builtin" : "Įmontuotas",
    "None" : "Nėra",
    "OAuth1" : "OAuth1",
    "App key" : "Trečiųjų šalių programinės įrangos identifikacijos raktas",
    "App secret" : "Trečiųjų šalių programinės įrangos slaptažodis",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliento ID",
    "Client secret" : "Trečiųjų šalių programinės įrangos kliento identifikacijos raktas",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Laikino valdytojo vardas",
    "Identity endpoint URL" : "Identiteto URL",
    "Rackspace" : "Rackspace",
    "API key" : "API raktas",
    "Global credentials" : "Globalūs prisijungimo duomenys",
    "Log-in credentials, save in database" : "Prisijungimo duomenys, saugoti duomenų bazėje",
    "Username and password" : "Naudotojo vardas ir slaptažodis",
    "Log-in credentials, save in session" : "Prisijungimo duomenys, saugoti sesijoje",
    "User entered, store in database" : "Naudotojas įvestas, saugoti duomenų bazėje",
    "RSA public key" : "RSA viešasis raktas",
    "Public key" : "Viešasis raktas",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Amazon S3 saugykla",
    "Hostname" : "Domeno vardas",
    "Port" : "Prievadas",
    "Region" : "Regionas",
    "Enable SSL" : "Įjungti SSL",
    "Enable Path Style" : "Amazon S3 kelias",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nuotolinis poaplankis",
    "Secure https://" : "Saugus https://",
    "FTP" : "FTP",
    "Host" : "Domenas",
    "Secure ftps://" : "Saugus ftps://",
    "Local" : "Vietinis",
    "Location" : "Vieta",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Šaknis",
    "SFTP with secret key login" : "SFTP protokolas su prisijungimu",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dalintis",
    "Domain" : "Domenas",
    "SMB / CIFS using OC login" : "SMB / CIFS, naudojant OC prisijungimą",
    "Username as share" : "Samba dalinimosi vardas",
    "OpenStack Object Storage" : "Objektų saugykla \"OpenStack\"",
    "Service name" : "Paslaugos vardas",
    "Request timeout (seconds)" : "Prisijungimo laikas (sekundėmis)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nėra įdiegta \"%s\". %s prijungimas yra neįmanomas. Paprašykite savo sistemos administratoriaus, kad įdiegtų trūkstamą paketą.",
    "No external storage configured" : "Nėra sukonfigūruota jokia išorinė saugykla",
    "You can add external storages in the personal settings" : "Galite pridėti papildomą išorinę saugyklą nustatymų skiltyje",
    "Name" : "Pavadinimas",
    "Storage type" : "Saugyklos tipas",
    "Scope" : "Leidimas",
    "Enable encryption" : "Įjungti šifravimą",
    "Enable previews" : "Leisti peržiūras",
    "Enable sharing" : "Leisti bendrinti",
    "Check for changes" : "Patikrinti ar nėra pakeitimų",
    "Never" : "Niekada",
    "Once every direct access" : "Kartą per tiesioginę peržiūrą",
    "Folder name" : "Aplanko pavadinimas",
    "External storage" : "Išorinė saugykla",
    "Authentication" : "Prisijungimas",
    "Configuration" : "Konfigūracija",
    "Available for" : "Prieinamas",
    "Add storage" : "Pridėti saugyklą",
    "Advanced settings" : "Išplėstiniai nustatymai",
    "Delete" : "Ištrinti",
    "Allow users to mount external storage" : "Leisti naudotojams prijungti išorines saugyklas",
    "Allow users to mount the following external storage" : "Leisti naudotojams prijungti šias išorines saugyklas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/lt_LT.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Išorinės saugyklos",
    "Personal" : "Asmeniniai",
    "System" : "Sistema",
    "Grant access" : "Suteikti prieigą",
    "Error configuring OAuth1" : "Klaida, konfigūruojant OAuth1",
    "Please provide a valid app key and secret." : "Prašome naudoti teisingus trečiųjų šalių programinės įrangos identifikacijos numerį ir slaptažodį.",
    "Error configuring OAuth2" : "Klaida, konfigūruojant OAuth2",
    "Generate keys" : "Sukurti raktus",
    "Error generating key pair" : "Klaida kuriant raktus",
    "All users. Type to select user or group." : "Visi naudotojai. Pradėkite rašyti, jei norite pasirinkti konkretų naudotoją ar grupę.",
    "(group)" : "(grupė)",
    "Compatibility with Mac NFD encoding (slow)" : "Suderinamumas su Mac NFD kodavimu (lėtai)",
    "Admin defined" : "Administratorius apibrėžtas",
    "Saved" : "Įrašyta",
    "Saving..." : "Įrašoma...",
    "Save" : "Įrašyti",
    "Empty response from the server" : "Negautas atsakymas iš serverio",
    "Couldn't access. Please log out and in again to activate this mount point" : "Prieiga yra neįmanoma. Pabandykite prisijungti iš naujo.",
    "Couldn't get the information from the remote server: {code} {type}" : "Neįmanoma gauti informacijos iš serverio: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nepavyko gauti išorinių prijungimo taškų sąrašo: {type}",
    "There was an error with message: " : "Klaidos žinutė:",
    "External mount error" : "Išorinio prijungimo klaida",
    "external-storage" : "išorinė saugykla",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Neįmanoma gauti duomenų sąrašo ir Windows tinkle prijungto disko. Nėra jokio atsakymo.",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Kai kurios sukonfigūruotos išorinės saugyklos nebuvo prijungtos. Paspauskite ant raudonai nuspalvotų eilučių norėdami gauti išsamesnę informaciją",
    "Please enter the credentials for the {mount} mount" : "Prašome įvesti prisijungimo duomenis skirtus saugyklos {mount} prijungimui",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Credentials saved" : "Prisijungimo duomenys yra išsaugoti",
    "Credentials saving failed" : "Nepavyko išsaugoti prisijungimo duomenų",
    "Credentials required" : "Reikalingi prisijungimo duomenys",
    "Storage with ID \"%d\" not found" : "Nerasta saugykla su identifikacijos numeriu \"%d\"",
    "Invalid backend or authentication mechanism class" : "Netinkama programinio kodo klasė realizuoja prisijungimo mechanizmą",
    "Invalid mount point" : "Neteisingas prijungimo taškas",
    "Objectstore forbidden" : "Objektų saugykla yra neprieinama",
    "Invalid storage backend \"%s\"" : "Netinkama saugyklos posistemė \"%s\"",
    "Not permitted to use backend \"%s\"" : "Neleidžiama naudoti posistemės \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Neleidžiama naudoti prisijungimo mechanizmo \"%s\"",
    "Unsatisfied backend parameters" : " Netinkami posistemės parametrai",
    "Unsatisfied authentication mechanism parameters" : "Netinkami parametrai perduoti į prisijungimo mechanizmą",
    "Insufficient data: %s" : "Trūksta duomenų: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Naudotojai negali redaguoti saugyklos identifikuotos kaip \"%d\"",
    "Access key" : "Prieigos raktas",
    "Secret key" : "Slaptažodis",
    "Builtin" : "Įmontuotas",
    "None" : "Nėra",
    "OAuth1" : "OAuth1",
    "App key" : "Trečiųjų šalių programinės įrangos identifikacijos raktas",
    "App secret" : "Trečiųjų šalių programinės įrangos slaptažodis",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliento ID",
    "Client secret" : "Trečiųjų šalių programinės įrangos kliento identifikacijos raktas",
    "Tenant name" : "Laikino valdytojo vardas",
    "Identity endpoint URL" : "Identiteto URL",
    "Domain" : "Domenas",
    "Rackspace" : "Rackspace",
    "API key" : "API raktas",
    "Global credentials" : "Globalūs prisijungimo duomenys",
    "Log-in credentials, save in database" : "Prisijungimo duomenys, saugoti duomenų bazėje",
    "Username and password" : "Naudotojo vardas ir slaptažodis",
    "Log-in credentials, save in session" : "Prisijungimo duomenys, saugoti sesijoje",
    "User entered, store in database" : "Naudotojas įvestas, saugoti duomenų bazėje",
    "RSA public key" : "RSA viešasis raktas",
    "Public key" : "Viešasis raktas",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Amazon S3 saugykla",
    "Hostname" : "Domeno vardas",
    "Port" : "Prievadas",
    "Region" : "Regionas",
    "Enable SSL" : "Įjungti SSL",
    "Enable Path Style" : "Amazon S3 kelias",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nuotolinis poaplankis",
    "Secure https://" : "Saugus https://",
    "FTP" : "FTP",
    "Host" : "Domenas",
    "Secure ftps://" : "Saugus ftps://",
    "Local" : "Vietinis",
    "Location" : "Vieta",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Šaknis",
    "SFTP with secret key login" : "SFTP protokolas su prisijungimu",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dalintis",
    "SMB / CIFS using OC login" : "SMB / CIFS, naudojant OC prisijungimą",
    "Username as share" : "Samba dalinimosi vardas",
    "OpenStack Object Storage" : "Objektų saugykla \"OpenStack\"",
    "Service name" : "Paslaugos vardas",
    "Request timeout (seconds)" : "Prisijungimo laikas (sekundėmis)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nėra įdiegta \"%s\". %s prijungimas yra neįmanomas. Paprašykite savo sistemos administratoriaus, kad įdiegtų trūkstamą paketą.",
    "Name" : "Pavadinimas",
    "Storage type" : "Saugyklos tipas",
    "Scope" : "Leidimas",
    "Enable encryption" : "Įjungti šifravimą",
    "Enable previews" : "Leisti peržiūras",
    "Enable sharing" : "Leisti bendrinti",
    "Check for changes" : "Patikrinti ar nėra pakeitimų",
    "Never" : "Niekada",
    "Once every direct access" : "Kartą per tiesioginę peržiūrą",
    "Folder name" : "Aplanko pavadinimas",
    "External storage" : "Išorinė saugykla",
    "Authentication" : "Prisijungimas",
    "Configuration" : "Konfigūracija",
    "Available for" : "Prieinamas",
    "Add storage" : "Pridėti saugyklą",
    "Advanced settings" : "Išplėstiniai nustatymai",
    "Delete" : "Ištrinti",
    "Allow users to mount external storage" : "Leisti naudotojams prijungti išorines saugyklas",
    "Allow users to mount the following external storage" : "Leisti naudotojams prijungti šias išorines saugyklas",
    "OpenStack" : "OpenStack",
    "No external storage configured" : "Nėra sukonfigūruota jokia išorinė saugykla",
    "You can add external storages in the personal settings" : "Galite pridėti papildomą išorinę saugyklą nustatymų skiltyje"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
